import { CompositeAlarm, Dashboard, IWidget } from "aws-cdk-lib/aws-cloudwatch";
import { Construct } from "constructs";
import { AddCompositeAlarmProps, AlarmFactory, AlarmFactoryDefaults, AlarmWithAnnotation, AwsConsoleUrlFactory, MetricFactory, MetricFactoryDefaults, Monitoring, MonitoringScope } from "../common";
import { IDashboardFactory, IDashboardSegment, IWidgetFactory, MonitoringDashboardsOverrideProps } from "../dashboard";
import { ApiGatewayMonitoringProps, ApiGatewayV2HttpApiMonitoringProps, AppSyncMonitoringProps, AutoScalingGroupMonitoringProps, BillingMonitoringProps, CertificateManagerMonitoringProps, CloudFrontDistributionMonitoringProps, CodeBuildProjectMonitoringProps, CustomMonitoringProps, DocumentDbMonitoringProps, DynamoTableGlobalSecondaryIndexMonitoringProps, DynamoTableMonitoringProps, Ec2ApplicationLoadBalancerMonitoringProps, EC2MonitoringProps, Ec2NetworkLoadBalancerMonitoringProps, Ec2ServiceMonitoringProps, ElastiCacheClusterMonitoringProps, FargateApplicationLoadBalancerMonitoringProps, FargateNetworkLoadBalancerMonitoringProps, FargateServiceMonitoringProps, GlueJobMonitoringProps, KinesisDataAnalyticsMonitoringProps, KinesisDataStreamMonitoringProps, KinesisFirehoseMonitoringProps, LambdaFunctionMonitoringProps, LogMonitoringProps, NetworkLoadBalancerMonitoringProps, OpenSearchClusterMonitoringProps, QueueProcessingEc2ServiceMonitoringProps, QueueProcessingFargateServiceMonitoringProps, RdsClusterMonitoringProps, RedshiftClusterMonitoringProps, S3BucketMonitoringProps, SecretsManagerSecretMonitoringProps, SimpleEc2ServiceMonitoringProps, SimpleFargateServiceMonitoringProps, SnsTopicMonitoringProps, SqsQueueMonitoringProps, SqsQueueMonitoringWithDlqProps, StepFunctionActivityMonitoringProps, StepFunctionLambdaIntegrationMonitoringProps, StepFunctionMonitoringProps, StepFunctionServiceIntegrationMonitoringProps, SyntheticsCanaryMonitoringProps, WafV2MonitoringProps } from "../monitoring";
import { MonitoringAspectProps } from "./MonitoringAspect";
export interface MonitoringFacadeProps {
    /**
     * Defaults for metric factory.
     * @default - empty (no preferences)
     */
    readonly metricFactoryDefaults?: MetricFactoryDefaults;
    /**
     * Defaults for alarm factory.
     * @default - actions enabled, facade logical ID used as default alarm name prefix
     */
    readonly alarmFactoryDefaults?: AlarmFactoryDefaults;
    /**
     * Defaults for dashboard factory.
     * @default - `DefaultDashboardFactory`; facade logical ID used as default name
     */
    readonly dashboardFactory?: IDashboardFactory;
}
/**
 * Main entry point to create your monitoring.
 */
export declare class MonitoringFacade extends MonitoringScope {
    protected readonly metricFactoryDefaults: MetricFactoryDefaults;
    protected readonly alarmFactoryDefaults: AlarmFactoryDefaults;
    protected readonly dashboardFactory?: IDashboardFactory;
    protected readonly createdSegments: IDashboardSegment[];
    constructor(scope: Construct, id: string, props?: MonitoringFacadeProps);
    private static getDefaultMetricFactoryDefaults;
    private static getDefaultAlarmFactoryDefaults;
    private static getDefaultDashboardFactory;
    createAlarmFactory(alarmNamePrefix: string): AlarmFactory;
    createAwsConsoleUrlFactory(): AwsConsoleUrlFactory;
    createMetricFactory(): MetricFactory;
    createWidgetFactory(): IWidgetFactory;
    createdDashboard(): Dashboard | undefined;
    createdSummaryDashboard(): Dashboard | undefined;
    createdAlarmDashboard(): Dashboard | undefined;
    /**
     * Returns the created alarms across all the monitorings added up until now.
     */
    createdAlarms(): AlarmWithAnnotation[];
    /**
     * Returns a subset of created alarms that are marked by a specific custom tag.
     * @param customTag tag to filter alarms by
     */
    createdAlarmsWithTag(customTag: string): AlarmWithAnnotation[];
    /**
     * Returns a subset of created alarms that are marked by a specific disambiguator.
     * @param disambiguator disambiguator to filter alarms by
     */
    createdAlarmsWithDisambiguator(disambiguator: string): AlarmWithAnnotation[];
    /**
     * Finds a subset of created alarms that are marked by a specific custom tag and creates a composite alarm.
     * This composite alarm is created with an 'OR' condition, so it triggers with any child alarm.
     * NOTE: This composite alarm is not added among other alarms, so it is not returned by createdAlarms() calls.
     *
     * @param customTag tag to filter alarms by
     * @param props customization options
     */
    createCompositeAlarmUsingTag(customTag: string, props?: AddCompositeAlarmProps): CompositeAlarm | undefined;
    /**
     * Finds a subset of created alarms that are marked by a specific disambiguator and creates a composite alarm.
     * This composite alarm is created with an 'OR' condition, so it triggers with any child alarm.
     * NOTE: This composite alarm is not added among other alarms, so it is not returned by createdAlarms() calls.
     *
     * @param alarmDisambiguator disambiguator to filter alarms by
     * @param props customization options
     */
    createCompositeAlarmUsingDisambiguator(alarmDisambiguator: string, props?: AddCompositeAlarmProps): CompositeAlarm | undefined;
    /**
     * Returns the created monitorings added up until now.
     */
    createdMonitorings(): Monitoring[];
    addSegment(segment: IDashboardSegment, overrideProps?: MonitoringDashboardsOverrideProps): MonitoringFacade;
    addLargeHeader(text: string, addToSummary?: boolean, addToAlarm?: boolean): MonitoringFacade;
    addMediumHeader(text: string, addToSummary?: boolean, addToAlarm?: boolean): MonitoringFacade;
    addSmallHeader(text: string, addToSummary?: boolean, addToAlarm?: boolean): MonitoringFacade;
    addWidget(widget: IWidget, addToSummary?: boolean, addToAlarm?: boolean): MonitoringFacade;
    monitorApiGateway(props: ApiGatewayMonitoringProps): MonitoringFacade;
    monitorApiGatewayV2HttpApi(props: ApiGatewayV2HttpApiMonitoringProps): MonitoringFacade;
    monitorAppSyncApi(props: AppSyncMonitoringProps): MonitoringFacade;
    monitorCertificate(props: CertificateManagerMonitoringProps): MonitoringFacade;
    monitorCloudFrontDistribution(props: CloudFrontDistributionMonitoringProps): MonitoringFacade;
    monitorCodeBuildProject(props: CodeBuildProjectMonitoringProps): MonitoringFacade;
    monitorDocumentDbCluster(props: DocumentDbMonitoringProps): MonitoringFacade;
    monitorDynamoTable(props: DynamoTableMonitoringProps): MonitoringFacade;
    monitorDynamoTableGlobalSecondaryIndex(props: DynamoTableGlobalSecondaryIndexMonitoringProps): MonitoringFacade;
    monitorEC2Instances(props: EC2MonitoringProps): MonitoringFacade;
    monitorElasticsearchCluster(props: OpenSearchClusterMonitoringProps): MonitoringFacade;
    monitorOpenSearchCluster(props: OpenSearchClusterMonitoringProps): MonitoringFacade;
    monitorElastiCacheCluster(props: ElastiCacheClusterMonitoringProps): MonitoringFacade;
    monitorGlueJob(props: GlueJobMonitoringProps): MonitoringFacade;
    monitorFargateService(props: FargateServiceMonitoringProps): MonitoringFacade;
    monitorSimpleFargateService(props: SimpleFargateServiceMonitoringProps): MonitoringFacade;
    monitorFargateNetworkLoadBalancer(props: FargateNetworkLoadBalancerMonitoringProps): MonitoringFacade;
    monitorFargateApplicationLoadBalancer(props: FargateApplicationLoadBalancerMonitoringProps): MonitoringFacade;
    monitorEc2Service(props: Ec2ServiceMonitoringProps): MonitoringFacade;
    monitorSimpleEc2Service(props: SimpleEc2ServiceMonitoringProps): MonitoringFacade;
    monitorEc2NetworkLoadBalancer(props: Ec2NetworkLoadBalancerMonitoringProps): MonitoringFacade;
    monitorEc2ApplicationLoadBalancer(props: Ec2ApplicationLoadBalancerMonitoringProps): MonitoringFacade;
    monitorQueueProcessingFargateService(props: QueueProcessingFargateServiceMonitoringProps): MonitoringFacade;
    monitorQueueProcessingEc2Service(props: QueueProcessingEc2ServiceMonitoringProps): MonitoringFacade;
    monitorAutoScalingGroup(props: AutoScalingGroupMonitoringProps): MonitoringFacade;
    monitorKinesisFirehose(props: KinesisFirehoseMonitoringProps): MonitoringFacade;
    monitorKinesisDataStream(props: KinesisDataStreamMonitoringProps): MonitoringFacade;
    monitorKinesisDataAnalytics(props: KinesisDataAnalyticsMonitoringProps): MonitoringFacade;
    monitorLambdaFunction(props: LambdaFunctionMonitoringProps): MonitoringFacade;
    monitorNetworkLoadBalancer(props: NetworkLoadBalancerMonitoringProps): MonitoringFacade;
    monitorRdsCluster(props: RdsClusterMonitoringProps): MonitoringFacade;
    monitorRedshiftCluster(props: RedshiftClusterMonitoringProps): MonitoringFacade;
    monitorSecretsManagerSecret(props: SecretsManagerSecretMonitoringProps): MonitoringFacade;
    monitorSnsTopic(props: SnsTopicMonitoringProps): MonitoringFacade;
    monitorSqsQueue(props: SqsQueueMonitoringProps): MonitoringFacade;
    monitorSqsQueueWithDlq(props: SqsQueueMonitoringWithDlqProps): MonitoringFacade;
    monitorStepFunction(props: StepFunctionMonitoringProps): MonitoringFacade;
    monitorStepFunctionActivity(props: StepFunctionActivityMonitoringProps): MonitoringFacade;
    monitorStepFunctionLambdaIntegration(props: StepFunctionLambdaIntegrationMonitoringProps): MonitoringFacade;
    monitorStepFunctionServiceIntegration(props: StepFunctionServiceIntegrationMonitoringProps): MonitoringFacade;
    monitorS3Bucket(props: S3BucketMonitoringProps): MonitoringFacade;
    monitorLog(props: LogMonitoringProps): MonitoringFacade;
    monitorSyntheticsCanary(props: SyntheticsCanaryMonitoringProps): MonitoringFacade;
    monitorWebApplicationFirewallAclV2(props: WafV2MonitoringProps): MonitoringFacade;
    monitorBilling(props?: BillingMonitoringProps): MonitoringFacade;
    monitorCustom(props: CustomMonitoringProps): MonitoringFacade;
    /**
     * Monitor all the resources in the given scope.
     * @param scope
     * @param aspectProps
     * @experimental
     */
    monitorScope(scope: Construct, aspectProps?: MonitoringAspectProps): void;
}
